@@ -34,7 +34,10 @@ and the fallback slowest single-threaded solutions when crawling.
 
 """
 
-from darc.process import process as darc  # pylint: disable=unused-import
+from darc.process import process as darc
+from darc.process import register as register_hooks  # pylint: disable=unused-import
+from darc.proxy import register as register_proxy  # pylint: disable=unused-import
+from darc.sites import register as register_sites  # pylint: disable=unused-import
 
 __all__ = ['darc']
-__version__ = '0.6.9'
+__version__ = '0.8.1.post1'
