@@ -22,7 +22,7 @@ copyright = '2019-2020, Jarry Shaw'
 author = 'Jarry Shaw'
 
 # The full version, including alpha/beta/rc tags
-release = '0.7.0'
+release = '0.8.1'
 
 
 # -- General configuration ---------------------------------------------------
@@ -34,7 +34,7 @@ extensions = [
     'sphinx.ext.viewcode',
     'sphinx.ext.intersphinx',
     'sphinx.ext.autodoc', 'sphinx.ext.autodoc.typehints',
-    'sphinxcontrib.napoleon',
+    'sphinx.ext.napoleon',
     'sphinx.ext.todo',
 ]
 
@@ -99,6 +99,21 @@ html_theme = 'alabaster'
 # so a file named "default.css" will overwrite the builtin "default.css".
 html_static_path = ['_static']
 
+# Theme options are theme-specific and customize the look and feel of a theme
+# further.  For a list of options available for each theme, see the
+# documentation.
+html_theme_options = {
+    'show_powered_by': False,
+    'github_user': 'JarryShaw',
+    'github_repo': 'darc',
+    'github_banner': True,
+    'github_type': 'star',
+    #'show_related': False,
+    #'note_bg': '#FFF59C',
+    #'travis_button': True,
+    #'codecov_button': True,
+}
+
 
 # -- Customised hooks --------------------------------------------------------
 
